@@ -1,4 +1,3 @@
-# coding: utf-8
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -19,7 +18,7 @@ class Group(Module):
 
     def __init__(self, name=None):
         self.name = name
-        super(Group, self).__init__()
+        super().__init__()
 
     @property
     def exists(self):
